@@ -426,9 +426,9 @@ class Model:
         if _type in [dict, set, list, bytes]:
             return len(obj)
         elif _type == datetime.datetime:
-            return (obj - datetime.min).total_seconds()
+            return (obj - datetime.datetime.min).total_seconds()
         elif _type == datetime.date:
-            return (obj - date.min).total_seconds()
+            return (obj - datetime.date.min).total_seconds()
         elif _type == datetime.time:
             result = obj.hour * 60 * 60 + obj.minute * 60 + obj.second + \
                      obj.microsecond / 1000
